"""init

Revision ID: 787b01c0212f
Revises: 
Create Date: 2023-05-27 03:37:07.240615

"""
from alembic import op
import sqlalchemy as sa
from sqlalchemy.dialects import postgresql


# revision identifiers, used by Alembic.
revision = '787b01c0212f'
down_revision = None
branch_labels = None
depends_on = None


def upgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    exchange_enum = postgresql.ENUM(name='exchange', schema='public', create_type=False)
    op.create_table('funding_rate',
    sa.Column('funding_rate', sa.DECIMAL(precision=7, scale=6), nullable=False),
    sa.Column('exchange', exchange_enum, nullable=False),
    sa.Column('symbol', sa.String(), nullable=False),
    sa.Column('timestamp', sa.BIGINT(), nullable=False),
    sa.Column('datetime', sa.DateTime(), nullable=False),
    sa.Column('id', sa.Integer(), nullable=False),
    sa.Column('created_at', sa.TIMESTAMP(), nullable=False),
    sa.Column('updated_at', sa.TIMESTAMP(), nullable=False),
    sa.PrimaryKeyConstraint('id'),
    schema='crypto'
    )
    op.create_index('ix_funding_rate_created_at', 'funding_rate', ['created_at'], unique=False, schema='crypto')
    op.create_index('ix_funding_rate_exchange_symbol_timestamp', 'funding_rate', ['exchange', 'symbol', 'timestamp'], unique=True, schema='crypto')
    op.create_index('ix_funding_rate_timestamp', 'funding_rate', ['timestamp'], unique=False, schema='crypto')
    op.create_index('ix_funding_rate_time_of_minute', 'funding_rate', [sa.text('EXTRACT(minute from datetime)')], unique=False, schema='crypto')
    op.create_index('ix_funding_rate_updated_at', 'funding_rate', ['updated_at'], unique=False, schema='crypto')
    op.create_table('funding_settlement',
    sa.Column('funding_rate', sa.DECIMAL(precision=7, scale=6), nullable=False),
    sa.Column('exchange', exchange_enum, nullable=False),
    sa.Column('symbol', sa.String(), nullable=False),
    sa.Column('timestamp', sa.BIGINT(), nullable=False),
    sa.Column('datetime', sa.DateTime(), nullable=False),
    sa.Column('id', sa.Integer(), nullable=False),
    sa.Column('created_at', sa.TIMESTAMP(), nullable=False),
    sa.Column('updated_at', sa.TIMESTAMP(), nullable=False),
    sa.PrimaryKeyConstraint('id'),
    schema='crypto'
    )
    op.create_index('ix_funding_settlement_created_at', 'funding_settlement', ['created_at'], unique=False, schema='crypto')
    op.create_index('ix_funding_settlement_exchange_symbol_timestamp', 'funding_settlement', ['exchange', 'symbol', 'timestamp'], unique=True, schema='crypto')
    op.create_index('ix_funding_settlement_timestamp', 'funding_settlement', ['timestamp'], unique=False, schema='crypto')
    op.create_index('ix_funding_settlement_time_of_minute', 'funding_settlement', [sa.text('EXTRACT(minute from datetime)')], unique=False, schema='crypto')
    op.create_index('ix_funding_settlement_updated_at', 'funding_settlement', ['updated_at'], unique=False, schema='crypto')
    op.create_table('long_short_ratio',
    sa.Column('long_account', sa.DECIMAL(precision=5, scale=4), nullable=False),
    sa.Column('short_account', sa.DECIMAL(precision=5, scale=4), nullable=False),
    sa.Column('long_short_ratio', sa.DECIMAL(precision=6, scale=4), nullable=False),
    sa.Column('exchange', exchange_enum, nullable=False),
    sa.Column('symbol', sa.String(), nullable=False),
    sa.Column('timestamp', sa.BIGINT(), nullable=False),
    sa.Column('datetime', sa.DateTime(), nullable=False),
    sa.Column('id', sa.Integer(), nullable=False),
    sa.Column('created_at', sa.TIMESTAMP(), nullable=False),
    sa.Column('updated_at', sa.TIMESTAMP(), nullable=False),
    sa.PrimaryKeyConstraint('id'),
    schema='crypto'
    )
    op.create_index('ix_long_short_ratio_created_at', 'long_short_ratio', ['created_at'], unique=False, schema='crypto')
    op.create_index('ix_long_short_ratio_exchange_symbol_timestamp', 'long_short_ratio', ['exchange', 'symbol', 'timestamp'], unique=True, schema='crypto')
    op.create_index('ix_long_short_ratio_timestamp', 'long_short_ratio', ['timestamp'], unique=False, schema='crypto')
    op.create_index('ix_long_short_ratio_time_of_minute', 'long_short_ratio', [sa.text('EXTRACT(minute from datetime)')], unique=False, schema='crypto')
    op.create_index('ix_long_short_ratio_updated_at', 'long_short_ratio', ['updated_at'], unique=False, schema='crypto')
    op.create_table('ohlcv',
    sa.Column('open', sa.Float(), nullable=False),
    sa.Column('high', sa.Float(), nullable=False),
    sa.Column('low', sa.Float(), nullable=False),
    sa.Column('close', sa.Float(), nullable=False),
    sa.Column('volume', sa.Float(), nullable=False),
    sa.Column('exchange', exchange_enum, nullable=False),
    sa.Column('symbol', sa.String(), nullable=False),
    sa.Column('timestamp', sa.BIGINT(), nullable=False),
    sa.Column('datetime', sa.DateTime(), nullable=False),
    sa.Column('id', sa.Integer(), nullable=False),
    sa.Column('created_at', sa.TIMESTAMP(), nullable=False),
    sa.Column('updated_at', sa.TIMESTAMP(), nullable=False),
    sa.PrimaryKeyConstraint('id'),
    schema='crypto'
    )
    op.create_index('ix_ohlcv_created_at', 'ohlcv', ['created_at'], unique=False, schema='crypto')
    op.create_index('ix_ohlcv_exchange_symbol_timestamp', 'ohlcv', ['exchange', 'symbol', 'timestamp'], unique=True, schema='crypto')
    op.create_index('ix_ohlcv_timestamp', 'ohlcv', ['timestamp'], unique=False, schema='crypto')
    op.create_index('ix_ohlcv_time_of_minute', 'ohlcv', [sa.text('EXTRACT(minute from datetime)')], unique=False, schema='crypto')
    op.create_index('ix_ohlcv_updated_at', 'ohlcv', ['updated_at'], unique=False, schema='crypto')
    op.create_table('open_interest',
    sa.Column('open_interest', sa.Float(), nullable=False),
    sa.Column('exchange', exchange_enum, nullable=False),
    sa.Column('symbol', sa.String(), nullable=False),
    sa.Column('timestamp', sa.BIGINT(), nullable=False),
    sa.Column('datetime', sa.DateTime(), nullable=False),
    sa.Column('id', sa.Integer(), nullable=False),
    sa.Column('created_at', sa.TIMESTAMP(), nullable=False),
    sa.Column('updated_at', sa.TIMESTAMP(), nullable=False),
    sa.PrimaryKeyConstraint('id'),
    schema='crypto'
    )
    op.create_index('ix_open_interest_created_at', 'open_interest', ['created_at'], unique=False, schema='crypto')
    op.create_index('ix_open_interest_exchange_symbol_timestamp', 'open_interest', ['exchange', 'symbol', 'timestamp'], unique=True, schema='crypto')
    op.create_index('ix_open_interest_timestamp', 'open_interest', ['timestamp'], unique=False, schema='crypto')
    op.create_index('ix_open_interest_time_of_minute', 'open_interest', [sa.text('EXTRACT(minute from datetime)')], unique=False, schema='crypto')
    op.create_index('ix_open_interest_updated_at', 'open_interest', ['updated_at'], unique=False, schema='crypto')
    # ### end Alembic commands ###


def downgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_index('ix_open_interest_updated_at', table_name='open_interest', schema='crypto')
    op.drop_index('ix_open_interest_time_of_minute', table_name='open_interest', schema='crypto')
    op.drop_index('ix_open_interest_timestamp_exchange_symbol', table_name='open_interest', schema='crypto')
    op.drop_index('ix_open_interest_created_at', table_name='open_interest', schema='crypto')
    op.drop_table('open_interest', schema='crypto')
    op.drop_index('ix_ohlcv_updated_at', table_name='ohlcv', schema='crypto')
    op.drop_index('ix_ohlcv_time_of_minute', table_name='ohlcv', schema='crypto')
    op.drop_index('ix_ohlcv_timestamp_exchange_symbol', table_name='ohlcv', schema='crypto')
    op.drop_index('ix_ohlcv_created_at', table_name='ohlcv', schema='crypto')
    op.drop_table('ohlcv', schema='crypto')
    op.drop_index('ix_long_short_ratio_updated_at', table_name='long_short_ratio', schema='crypto')
    op.drop_index('ix_long_short_ratio_time_of_minute', table_name='long_short_ratio', schema='crypto')
    op.drop_index('ix_long_short_ratio_timestamp_exchange_symbol', table_name='long_short_ratio', schema='crypto')
    op.drop_index('ix_long_short_ratio_created_at', table_name='long_short_ratio', schema='crypto')
    op.drop_table('long_short_ratio', schema='crypto')
    op.drop_index('ix_funding_settlement_updated_at', table_name='funding_settlement', schema='crypto')
    op.drop_index('ix_funding_settlement_time_of_minute', table_name='funding_settlement', schema='crypto')
    op.drop_index('ix_funding_settlement_timestamp_exchange_symbol', table_name='funding_settlement', schema='crypto')
    op.drop_index('ix_funding_settlement_created_at', table_name='funding_settlement', schema='crypto')
    op.drop_table('funding_settlement', schema='crypto')
    op.drop_index('ix_funding_rate_updated_at', table_name='funding_rate', schema='crypto')
    op.drop_index('ix_funding_rate_time_of_minute', table_name='funding_rate', schema='crypto')
    op.drop_index('ix_funding_rate_timestamp_exchange_symbol', table_name='funding_rate', schema='crypto')
    op.drop_index('ix_funding_rate_created_at', table_name='funding_rate', schema='crypto')
    op.drop_table('funding_rate', schema='crypto')
    # ### end Alembic commands ###
